@@ -1,4 +1,4 @@
-# Copyright (c) 2012, cPanel, Inc.
+# Copyright (c) 2014, cPanel, Inc.
 # All rights reserved.
 # http://cpanel.net/
 #
@@ -14,8 +14,7 @@ use Filesys::POSIX::Bits;
 use Filesys::POSIX::Path            ();
 use Filesys::POSIX::Real::Inode     ();
 use Filesys::POSIX::Real::Directory ();
-
-use Carp qw/confess/;
+use Filesys::POSIX::Error qw(throw);
 
 =head1 NAME
 
@@ -27,8 +26,8 @@ Filesys::POSIX::Real - Portal to actual underlying filesystem
     use Filesys::POSIX::Real;
 
     my $fs = Filesys::POSIX->new(Filesys::POSIX::Real->new,
-        'special'   => 'real:/home/foo/test',
-        'noatime'   => 1
+        'path'    => '/home/foo/test',
+        'noatime' => 1
     );
 
 =head1 DESCRIPTION
@@ -115,14 +114,13 @@ Exceptions will be thrown for the following:
 
 =over
 
-=item Invalid special path
+=item * EINVAL (Invalid argument)
 
-The format of the C<$data{'special'}> argument does not match the aforementioned
-specification.
+No value was specified for C<$data{'path'}>.
 
-=item Not a directory
+=item * ENOTDIR (Not a directory)
 
-The path specified in C<$data{'special'}> on the real filesystem does not
+The path specified in C<$data{'path'}> on the real filesystem does not
 correspond to an actual directory.
 
 =back
@@ -134,14 +132,11 @@ correspond to an actual directory.
 sub init {
     my ( $self, %data ) = @_;
 
-    my $path = $data{'path'} or Carp::confess('Invalid argument');
+    my $path = $data{'path'} or throw &Errno::EINVAL;
 
-    my $root = Filesys::POSIX::Real::Inode->from_disk(
-        $path,
-        'dev' => $self
-    );
+    my $root = Filesys::POSIX::Real::Inode->from_disk( $path, 'dev' => $self );
 
-    confess('Not a directory') unless $root->dir;
+    throw &Errno::ENOTDIR unless $root->dir;
 
     $self->{'flags'} = \%data;
     $self->{'path'}  = Filesys::POSIX::Path->full($path);
@@ -151,3 +146,24 @@ sub init {
 }
 
 1;
+
+__END__
+
+=head1 AUTHOR
+
+Written by Xan Tronix <xan@cpan.org>
+
+=head1 CONTRIBUTORS
+
+=over
+
+=item Rikus Goodell <rikus.goodell@cpanel.net>
+
+=item Brian Carlson <brian.carlson@cpanel.net>
+
+=back
+
+=head1 COPYRIGHT
+
+Copyright (c) 2014, cPanel, Inc.  Distributed under the terms of the Perl
+Artistic license.
