@@ -1,4 +1,4 @@
-# Copyright (c) 2012, cPanel, Inc.
+# Copyright (c) 2014, cPanel, Inc.
 # All rights reserved.
 # http://cpanel.net/
 #
@@ -13,11 +13,7 @@ use warnings;
 sub new {
     my ( $class, $mountpoint, $root ) = @_;
 
-    return bless {
-        %$root,
-        'parent' => $mountpoint->{'parent'}
-      },
-      ref $root;
+    return bless { %$root, 'parent' => $mountpoint->{'parent'} }, ref $root;
 }
 
 1;
